<?php 
/**
 * Classic Editor
 *
 * Plugin Name: WebArtisan - WAmaps
 * Plugin URI:  https://www.wa-maps.de
 * Description: With WAmaps you can create privacy-compliant maps. Use as many markers as you like, which can be filtered and style the maps completely individually.
 * Version:     1.1
 * Author:      Loreberry UG (haftungsbeschränkt) - WAmaps
 * Author URI:  https://webartisan.de
 * License:     GPLv2 or later
 * License URI: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * Text Domain: wamaps
 * Domain Path: /languages
 * Requires at least: 4.9
 * Tested up to: 5.8
 * Requires PHP: 5.4
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the GNU
 * General Public License version 2, as published by the Free Software Foundation. You may NOT assume
 * that you can use any other version of the GPL.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
 
class WA_Maps { 

	private $api_url = 'https://api.wa-maps.de/v1/webhook';
	
	function __construct(){
		add_action( 'admin_enqueue_scripts', array($this, 'wa_maps_backend_enqueue_scripts' ));
		add_action( 'wp_enqueue_scripts', array($this, 'wa_maps_frontend_enqueue_scripts' ));
		add_action( 'admin_menu', array($this,'settings') );
		add_shortcode('wa_maps', array($this, 'shortcode_wa_maps'));
	}
	
	public function wa_maps_backend_enqueue_scripts(){
		wp_enqueue_style('wa_maps_style', plugins_url('css/backend/style.css',__FILE__ ));
		wp_enqueue_script('wa_maps_script', plugins_url('js/backend/scripts.js',__FILE__ ));
	}
	
	public function wa_maps_frontend_enqueue_scripts(){
		wp_enqueue_style('wa_maps_style', plugins_url('css/frontend/style.css',__FILE__ ));
	}
	
	public function settings() {
        add_menu_page(
            __( 'WA-Maps', 'wa' ),
            __( 'WA-Maps', 'wa' ),
            'manage_options',
            'wa-maps-settings',
            array($this, 'wa_page_settings'),
            plugin_dir_url(__FILE__).'wa_logo.svg',
            -1
        );
	}
	
	public function wa_page_settings(){
		if(isset($_REQUEST['submit'])){
			$this->set_api_key($_REQUEST['api_key']);
		}
		$status = '';
		if(!get_option('wa_maps_status') || get_option('wa_maps_status') == 0){
			$status = '<div class="wa_maps_status inactive">Inaktiv</div>';
		}else{
			$status = '<div class="wa_maps_status active">Aktiv</div>';
		}
		
		$str 	= 	'<div class="wrap">';
		$str 	.= 		'<div class="wa_settings_container">
							<h1>'.esc_html( 'Einstellungen', 'wa' ).'</h1>
						</div>
						<div class="wa_settings_content">
							<div class="wa_settings_notice">Sie finden Ihren API Key in Ihrem Dashboard unter <a target="_blank" href="dashboard.wa-map.de">dashboard.wa-map.de</a></div>
							'.(get_option('wa_maps_status') == '0' ? '<div class="wa_settings_notice error">'.get_option('wa_maps_message').'</div>' : '').'
							<form method="post" name="wa_setting_form" class="wa_setting_form">
								<div class="wa_setting_form_inner">
									<label for="api_key">Lizenz</label>
									<input type="text" value="'.get_option('wa_maps_api_key').'" placeholder="API Key eingeben" name="api_key" />
									'.$status.'
								</div>
							<p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="Save Changes"></p>
							</form>
						</div>
					</div>';
		echo $str;
	}
	
	public function shortcode_wa_maps($atts){
		if(get_option('wa_maps_status') == '1'){
			$map_id_url = '';
			if(isset($atts['id'])){
				$map_id_url = '&map='.$atts['id'];
			}

			$html = '';

			$html .= '
			<script src="https://api.wa-maps.de/v1/coords_germany_states.js"></script>
			<script src="https://api.wa-maps.de/v1/api_maps.js?key='.get_option('wa_maps_api_key').$map_id_url.'"></script>
			<link rel="stylesheet" type="text/css" href="https://api.wa-maps.de/v1/api_maps.css">
			<div class="map-container">
				<div id="map"></div>
			</div>';
			return $html;
		}
	}
	
	public function set_api_key($key){
		$ch = curl_init( $this->api_url.'/'.$key.'/checkApikey' );
		curl_setopt( $ch, CURLOPT_HTTPHEADER, array('Content-Type:application/json'));
		curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
		curl_setopt( $ch, CURLOPT_CONNECTTIMEOUT, 30);
		curl_setopt( $ch, CURLOPT_POST, 1);
		$payload = json_encode( array( "domain"=> $_SERVER['SERVER_NAME'] ) );
		curl_setopt( $ch, CURLOPT_POSTFIELDS, $payload );

		$result = curl_exec($ch);
		$res = json_decode($result);

		if($res->status == 200){
			update_option('wa_maps_api_key', $key);
			update_option('wa_maps_status', 1);
			update_option('wa_maps_message', $res->success);
		}else{
			update_option('wa_maps_api_key', $key);
			update_option('wa_maps_status', 0);
			update_option('wa_maps_message', $res->error);
		}		
	}
}

new WA_Maps();